summaryrefslogtreecommitdiffstats
path: root/src/opt/fxu/fxuPair.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/opt/fxu/fxuPair.c')
-rw-r--r--src/opt/fxu/fxuPair.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/opt/fxu/fxuPair.c b/src/opt/fxu/fxuPair.c
index 87645cc7..62cc792b 100644
--- a/src/opt/fxu/fxuPair.c
+++ b/src/opt/fxu/fxuPair.c
@@ -86,7 +86,7 @@ void Fxu_PairCanonicize( Fxu_Cube ** ppCube1, Fxu_Cube ** ppCube2 )
pLit2 = pLit2->pHNext;
continue;
}
- assert( pLit1 && pLit2 ); // this is true if the covers are SCC-free
+ assert( pLit1 && pLit2 ); // this is true if the covers are SCC-ABC_FREE
if ( pLit1->iVar > pLit2->iVar )
{ // swap the cubes
pCubeTemp = *ppCube1;
@@ -149,7 +149,7 @@ unsigned Fxu_PairHashKeyArray( Fxu_Matrix * p, int piVarsC1[], int piVarsC2[], i
Synopsis [Computes the hash key of the divisor represented by the pair of cubes.]
Description [Goes through the variables in both cubes. Skips the identical
- ones (this corresponds to making the cubes cube-free). Computes the hash
+ ones (this corresponds to making the cubes cube-ABC_FREE). Computes the hash
value of the cubes. Assigns the number of literals in the base and in the
cubes without base.]
@@ -178,7 +178,7 @@ unsigned Fxu_PairHashKey( Fxu_Matrix * p, Fxu_Cube * pCube1, Fxu_Cube * pCube2,
if ( pLit1 && pLit2 )
{
if ( pLit1->iVar == pLit2->iVar )
- { // ensure cube-free
+ { // ensure cube-ABC_FREE
pLit1 = pLit1->pHNext;
pLit2 = pLit2->pHNext;
// add this literal to the base
@@ -452,8 +452,8 @@ void Fxu_PairAllocStorage( Fxu_Var * pVar, int nCubes )
// assert( pVar->nCubes == 0 );
pVar->nCubes = nCubes;
// allocate memory for all the pairs
- pVar->ppPairs = ALLOC( Fxu_Pair **, nCubes );
- pVar->ppPairs[0] = ALLOC( Fxu_Pair *, nCubes * nCubes );
+ pVar->ppPairs = ABC_ALLOC( Fxu_Pair **, nCubes );
+ pVar->ppPairs[0] = ABC_ALLOC( Fxu_Pair *, nCubes * nCubes );
memset( pVar->ppPairs[0], 0, sizeof(Fxu_Pair *) * nCubes * nCubes );
for ( k = 1; k < nCubes; k++ )
pVar->ppPairs[k] = pVar->ppPairs[k-1] + nCubes;
@@ -497,8 +497,8 @@ void Fxu_PairFreeStorage( Fxu_Var * pVar )
{
if ( pVar->ppPairs )
{
- FREE( pVar->ppPairs[0] );
- FREE( pVar->ppPairs );
+ ABC_FREE( pVar->ppPairs[0] );
+ ABC_FREE( pVar->ppPairs );
}
}